(function ($) {

/*** This document contains theme functions specific to menus and the main menu region ***/

  /*****************************************************
  *** main menu behavior
  *****************************************************/
  Drupal.behaviors.wcmOmegaAccessibleMenu = {
    attach: function (context, settings) {

      function navigate(group, index) {
        if (index >= 0 && index < group.length) {
          group.get(index).focus();
        }
      }

      var items = $('ul#superfish-1 a');

      items.each(function(index) {
        /* START tab key ptions */
        if (index != 0) {
          $(this).attr('tabindex', '-1');
        }

        /* (above) Onlu first parent tabbable OR All parents tabbable (below) */

        // $(this).not('.sf-depth-1').attr('tabindex', '-1');

        /* END tab key ptions */
      });

      items.on('keydown', function(e){
        var key = e.which;

        if (key > 36 && key < 41) {
          e.preventDefault();

          // left/right keys
          if (key % 2) {

            var parents = items.filter('.sf-depth-1');
            var index = parents.index(this);

            if (index < 0) {
              index = parents.index($(this).parents('.sf-depth-1').find('a.sf-depth-1').get(0));
            }

            navigate(parents, index + key - 38);
          }
          // up/down keys
          else {
            /* START Up/Down Options */

            // navigate(items, items.index(this) + key - 39);

            /* (above) Navigate through ALL links OR Only children in current section (below) */

            var children = $(this).parents('.main-menu-second-ul').find('a');
            if (!children.length){
              children = $(this).next('.main-menu-second-ul').find('a');
            }

            var index = children.index(this) + key - 39;
            if (index < 0) {
              index = children.length - 1;
            }
            else if (index >= children.length) {
              index = 0;
            }
            children.get(index).focus();

            /* END Up/Down Options */
          }
        }
      });
    }
  };

  Drupal.behaviors.wcmOmegaMainMenu = {
    attach: function (context, settings) {

      //adds classes to main menu elements by level
      //to standardlize classes across superfish and menu-block modules
      $('ul#superfish-1 > li').addClass('main-menu-top-li');
      $('.main-menu-top-li > ul').addClass('main-menu-second-ul');
      $('#block-menu-block-custom-1 ul.menu').addClass('main-menu-second-ul');
      $('.main-menu-second-ul > li').addClass('main-menu-second-li');
      $('.main-menu-second-ul > li > ul > li').addClass('main-menu-third-plus-li').removeClass('main-menu-second-li');

      //behavior for second-level menu
      if($('body').hasClass('menu-style-2')) {

        //hides li levels 3 and greater
        $('.main-menu-third-plus-li').hide();

        //shifts and adjusts menu based on window size and content
        var menuShift = function() {

          //menu width
          $('.main-menu-top-li > .main-menu-second-ul').each(function(){
            var ul2 = $(this);
            var ul2_width = ul2.css('width');
            var l_width = $('.l-constrained').css('width');

            //set width of hovered second level ul based on width of l-consrained
            ul2.css('width',l_width);
          })

          //determine height after width is applied above
          // applies menu height classes to parents
          $('li[class*="sf-item-"] > ul').each(function(){
            var hgt = $(this).css('height');
            $(this).parent().addClass('hgt-'+ hgt);
          })

          //changes height of second menu wrapper based on "hgt-"class on hover of main-menu-top-li
          $('.menuparent.main-menu-top-li').each(function(){
            //extracts height from "hgt-" class
            $('[class*="hgt-"]').each(function(){
              var hgtClass = $.map($(this)[0].classList, function(cls, i) {
                if (cls.indexOf('hgt-') === 0) {
                  return cls.replace('hgt-', '');
                }
              })
              $(this).hover(function(){
                $('.l-region--main-menu-second-wrapper').css('height', hgtClass).addClass('menu-hover');
                $('#block-menu-block-custom-1').hide();
              },function(){
                $('.l-region--main-menu-second-wrapper').css('height', 'auto').removeClass('menu-hover');
                $('#block-menu-block-custom-1').show();
              })
            })
          })

          //position of first menu item
          var ul1_left = $('ul#superfish-1 .sf-item-1').position().left;

          //finds the position of each second level ul hover and shifts it to left align with first item
          $('.main-menu-top-li').each(function(){
            var ulx = $(this);
            var ulx_left = ulx.position().left;
            var shift = -(ulx_left - ul1_left);

            $(this).find('.main-menu-second-ul').css('margin-left', shift);
          })

        }//end menuShift

        $(window).on('load resize', menuShift);
      };
    }
  }

  /*****************************************************
  *** Adds/alters classes for mean-menu
  *****************************************************/
  Drupal.behaviors.wcmOmegaMeanMenu = {
		attach: function (context, settings) {
  		$(".mean-container .mean-nav ul li span").addClass("nolink");
		}
  };


  /*****************************************************
  *** adds functionality for search box in the menu bar
  *****************************************************/
  Drupal.behaviors.wcmOmegaSearchBlock = {
    attach: function (context, settings) {

      var toggleButton      = $('#search-block-toggle');
      var searchBox         = $('.l-region--main-menu #search-block-form');

      /**
       * The following reacts to clicks anywhere. If the click is within the
       * search box, the search box will stay visible. If the click is outside the
       * search box, the search box will be dismissed.
       */
      $(document).click(function(event) {
        toggleSearchBox(event);
      });

      toggleButton.keypress(function(event){
        if (event.which === 13) {
          toggleSearchBox(event);
        }
      });

      function toggleSearchBox(event) {
        var clickTarget = $(event.target).eq(0);
        if (clickTarget.attr('id') == toggleButton.attr('id')) {
          // Clicked the toggle button.
          if (searchBox.is(':visible') ){
            // Turn sticky visibility on.
            hideHoverSearchBox();
          }
          else {
            showHoverSearchBox();
          }
        }
        else if (clickedSearchBox(event)) {
          return;
        }
        else if (searchBox.is(':visible')) {
          // This only matters if the search box is currently visible.
          hideHoverSearchBox(true);
        }
      }

      /*
       * Determines if the target clicked was inside the search box.
       */
      function clickedSearchBox(event) {
        var clickTarget = $(event.target).eq(0);
        var inSearchBox = false;
        // Check if the search box itself was clicked.
        if (searchBox.get(0) == clickTarget.get(0)) {
          // Search box was clicked.
          inSearchBox = true;
        }
        else {
          /*
           * Compare the click target against all the elements in the search box
           * to determine if the clicked element is part of it.
           */
          var elements = searchBox.find('*');
          elements.each(function(index) {
            if (elements.eq(index).get(0) == clickTarget.get(0)) {
              // Search box element was clicked.
              inSearchBox = true;
              return;
            }
          });
        }
        return inSearchBox;
      }

      /*
       * Displays the hover search box.
       */
      function showHoverSearchBox() {
        searchBox.stop(true, true).clearQueue().fadeIn('fast');
        toggleButton.attr('aria-expanded', 'true').addClass('fa-search-minus');
      }

      /*
       * Hides the hover search box when applicable.
       *
       * @param force
       *   If set to TRUE, forces the search box to be hidden and disables
       *   the sticky visibility parameter.
       */
      function hideHoverSearchBox(force) {

        if (force != undefined) {
          if (force === true) {
            // Hide the box and turn sticky visibility off.
            hideHoverSearchBox_do();
            return;
          }
        }

        if (!searchBox.is(':focus')) {
          hideHoverSearchBox_do();
        }
      }

      function hideHoverSearchBox_do() {
        // Handles the actual hiding, without any logical operations.
        searchBox.stop(true, true).fadeOut('fast')
        toggleButton.attr('aria-expanded', 'false').removeClass('fa-search-minus');
      }

    }
  };


})(jQuery);
