(function ($) {

  /**
   * The recommended way for producing HTML markup through JavaScript is to write
   * theming functions. These are similiar to the theming functions that you might
   * know from 'phptemplate' (the default PHP templating engine used by most
   * Drupal themes including Omega). JavaScript theme functions accept arguments
   * and can be overriden by sub-themes.
   *
   * In most cases, there is no good reason to NOT wrap your markup producing
   * JavaScript in a theme function.
   */


  Drupal.behaviors.wcmOmegaAnchorScroll = {
    attach: function (context, settings) {
      // Scroll to anchors in jQuery UI widgets on page load or if hash in URL changes.
      $(window).on('load hashchange',function() {

        var anchor = window.location.hash;

        // If anchor exists, determine if it lives in a jQuery UI widget.
        if (anchor) {
          var target = $(anchor);
          var parent = target.parents('.ui-widget')

          if (parent.hasClass('ui-accordion')) {
            var method = 'accordion';
            var selector = '.accordion-item'
          }
          else if (parent.hasClass('ui-tabs')) {
            var method = 'tabs';
            var selector = '.ui-tabs-content'
          }

          if (method) {
            var parentPanel = target.parents(selector);
            var activeIndex = parent[method]('option', 'active');
            var targetIndex = parent.find(selector).index(parentPanel);

            if (activeIndex != targetIndex) {
              // Activate the widget element containing the anchor and recsompute panel height.
              parent[method]('option', 'active', targetIndex);

              // Scroll to the target anchor (and account for navbar height)
              setTimeout(function(){
                $('html, body').animate({scrollTop: target.offset().top - $('#navbar-bar').height() * 2}, 0);
              }, 410);
            }
          }
        }
      });

      // Trigger hashchange event if target of clicked link is on the current page (and ignore tab headers)
      $('a').click(function() {
        if (this.hash && window.location.pathname == this.pathname && !$(this).hasClass('ui-tabs-anchor')) {
          $(window).trigger('hashchange');
        }
      });
    }
  }

  /*** MatchHeight support ***/
  Drupal.behaviors.wcmOmegaMatchHeights = {
    attach: function (context, settings) {

      if ($.fn.matchHeight) {
        /* Match tile panes to equal height by row */
        var rows = $('.node-type-ocio-landing-page .row-tiles .row-fluid');
        rows.each(function() {
          var resize = false;

          var row = $(this);
          var regions = row.find('.tile-panel');
          regions.each(function(row){

            if ($(this).find('.pane-bundle-tile-pane-plus-text-area, .pane-bundle-tile-pane').size() == 1 ) {
              resize = true;
              return true;
            }
          });

          if (resize) {
            var panes = row.find('.tile-panel .pane-bundle-tile-pane-plus-text-area, .tile-panel .pane-bundle-tile-pane');
            panes.find('.text-areas, .title-box').matchHeight({byRow: false});
            panes.matchHeight({byRow: false});
          }
        });
      }

    }
  };


/*** If browser has no svg support, replace svg images with pngs ***/
  Drupal.behaviors.wcmOmegaSVGFallback = {
		attach: function (context, settings) {

      $('.no-svg img', context).each(function() {
        var src = $(this).attr('src').split('.');
        if (src.pop().toLowerCase() == 'svg') {
          src.push('png');
          $(this).attr('src', src.join('.'));
        }
      });

		}
  };


/*** removes zurb responsive table classes for selected items ***/
  Drupal.behaviors.wcmOmegaExcludeZurb = {
		attach: function (context, settings) {
  		//remove for panel panes that are not full width
  		$(".panel-display .span3 table").removeClass("responsive");
      $(".panel-display .span4 table").removeClass("responsive");
  		$(".panel-display .span6 table").removeClass("responsive");

  		//remove for views -- checking with moe first
		}
  };


/*** Adjustments for Media Magnet ***/
  Drupal.behaviors.wcmOmegaMediaMagnet = {
		attach: function (context, settings) {

      /* Move Media Magnet channel icon to title area if only one channel is selected */
      $(document).ajaxSuccess(function( event, request, settings ) {
        if (settings.url.indexOf("mediamagnet.osu.edu/api") >= 0 ) {
          $('.pane-mm-widgets-live-pane.mm-channel-type-undefined').each(function() {
            panel = $(this);
            icons = panel.find('.item i.fa');
            panel.find('.fa-fw').attr('class',function(index, classes) {
              var newClass = icons.first().attr('class').match(/fa-[^\s]+/g);
              if (newClass) {
                panel.removeClass('mm-channel-type-undefined');
                classes = classes.replace('fa-fw', newClass);
                icons.remove();
                $(this).find('.element-invisible').text(newClass);
              }
              return classes;
            });
          });
        }
      });

		}
  };


  /*** detects if text panels pane has only a title and adds class of "title-only" ***/
  Drupal.behaviors.wcmOmegaPaneType = {
		attach: function (context, settings) {

      $('.pane-bundle-text').not(':has(p)').closest('.pane-bundle-text').addClass('title-only');

		}
  };

  /*** removes sidebar classes for landing pages - classes were originally added to page div by omega ***/
  Drupal.behaviors.wcmOmegaLandingPage = {
		attach: function (context, settings) {

      if ($("body").hasClass("node-type-ocio-landing-page")) {
        $(".l-page").removeClass("has-one-sidebar has-two-sidebars has-sidebar-1 has-sidebar-2");
      }

		}
  };

  /*** news archive block nested accordion behavior ***/
  Drupal.behaviors.wcmOmegaNewsArchive = {
		attach: function (context, settings) {

      var active_link = $('.view-display-id-archive_listing_block .views-field-title a.active');

      //if we are on a news article page, open all accordions to active link on page load
      if ($(active_link).size()) {

        //close year accodion and remove nested-accordion class
        $('.view-display-id-archive_listing_block .ui-accordion-header').parent().hide();
        $('.view-grouping-header').removeClass('nested-accordion');

        // open all parents of the active link
        $(active_link).closest('.views-row').addClass('open');
        $('.views-row.open').parents().show();

        //add active classes back to each parent accordion
        $(active_link).closest('.view-grouping').addClass('active');
        $('.view-grouping.active .view-grouping-header').addClass('nested-accordion');
        $('.view-grouping.active .ui-accordion-header').addClass('ui-state-active');
        $('.view-grouping.active .ui-accordion-header span').addClass('ui-icon-triangle-1-s').removeClass('ui-icon-triangle-1-e');
      }

		}
  };

  /*** hides views-group-header if only one group is chosen in user contact view panes ***/
  Drupal.behaviors.wcmOmegaUserContact = {
    attach: function (context, settings) {

      var group = $('.pane-views-panes .view-content .views-group');
      var group_header = $('.pane-views-panes .view-content .views-group-header');
      var num_groups = group.length;

      if (num_groups == 1) {
        group_header.hide();
      }
    }
  };

  //adds classes to news client article nodes based on sidebar being empty or not
  Drupal.behaviors.wcmOmegaNewsArticle = {
    attach: function (context, settings) {

      var article = $('.node--full');
      var sidebar = $('.node--article--full .field--name-field-sidebar');
      var sidebar2 = $('.node--news-client-cached-article--full .field--name-news-client-sidebar');

      if(sidebar.length || sidebar2.length) {
        article.addClass('has-sidebar');
      } else {
        article.addClass('no-sidebar');
      }

    }
  }
  
  
  //adjustments for ocio_calendar
  Drupal.behaviors.wcmOmegacalendar = {
    attach: function (context, settings) {
    
    // if calendar entry node
    if($('.node-type-calendar-entry').length) {
      //find pipe character and assign class      
      var pipe ="|";
      var pipeSpan = $('.node-type-calendar-entry .field--name-field-date').html().replace(pipe, '<span class="pipe">' + pipe + '</span>');
      
      $('.node-type-calendar-entry .field--name-field-date').html(pipeSpan);
      
      //add font awesome icons
      $('.field--name-field-date').before('<i class="fa fa-calendar" aria-hidden="true"></i>');
      $('.group-location').before('<i class="fa fa-map-marker" aria-hidden="true"></i>');
      
      
    } //end if calendar entry node
      

      
      


    }
  }


})(jQuery);
